MatchMakerMonitoring.filled\_input\_elements
================================================================

.. currentmodule:: alfred3_interact.page

.. autoproperty:: MatchMakerMonitoring.filled_input_elements
